Stack

Struct Stack 

pub(crate) struct Stack {
    types: PackedTypes,
    amounts: [NonZero<usize>; 102],
    depth: u8,
}
A non-allocating Vec.

This has a maximum depth premised on the bound for an EPEE’s object depth.

Fields

types: PackedTypes

The type of the item being read.

amounts: [NonZero<usize>; 102]

The amount remaining for the item being read.

depth: u8

The current depth of the stack.

This is analogous to the length of a Vec, yet we use the term depth to distinguish how it tracks the depth of an object, not the amount of items present (which would be a function of depth and width, as noted above).

Implementations

Source

impl Stack

pub(crate) fn root_object() -> Self

Create a new stack to use with decoding the root object.

pub(crate) fn depth(&self) -> usize

The current stack depth.

pub(crate) fn peek(&self) -> Option<(TypeOrEntry, NonZero<usize>)>

Peek the current item on the stack.

pub(crate) fn pop(&mut self) -> Option<TypeOrEntry>

Pop the next item from the stack.

pub(crate) fn push( &mut self, kind: TypeOrEntry, amount: usize, ) -> Result<(), EpeeError>

Push an item onto the stack.

Source

impl Stack

pub(crate) fn single_step<'encoding, B: BytesLike<'encoding>>( &mut self, encoding: &mut B, ) -> Result<Option<SingleStepResult<'encoding, B>>, EpeeError>

Execute a single step of the decoding algorithm.

Returns Some((key, kind, len)) if an entry was read, or None otherwise. This also returns None if the stack is empty.

pub(crate) fn step<'encoding, B: BytesLike<'encoding>>( &mut self, encoding: &mut B, ) -> Result<Option<()>, EpeeError>

Step through the entirety of the next item.

Returns None if the stack is empty.